#!/usr/bin/env ruby
#
# Samizdat material item exchange
#
#   Copyright (c) 2002-2004  Dmitry Borodaenko <angdraug@debian.org>
#
#   This program is free software.
#   You can distribute/modify this program under the terms of
#   the GNU General Public License version 2 or later.
#

require 'samizdat'

# todo: implement material items exchange
request do |session|
    session.template.page(_('Not Implemented'),
        _('<p>Material item exchange is not implemented yet.</p>'))
end
